.. This is your project NEWS file which will contain the release notes.
.. Example: http://www.python.org/download/releases/2.6/NEWS.txt
.. The content of this file, along with README.rst, will appear in your
.. project's PyPI page.

News
====

0.3
---

*Release date: 12-Mar-2012*

* fix to recognize 1080p format (thanks to Jonathan Lauwers)

0.3b2
-----

*Release date: 2-Mar-2012*

* fixed the package installation

0.3b1
-----

*Release date: 1-Mar-2012*

* refactored quite a bit, code is much cleaner now
* fixed quite a few tests
* re-vamped the documentation, wrote some more

0.2
---

*Release date: 27-May-2011*

* new parser/matcher completely replaced the old one
* quite a few more unittests and fixes


0.2b1
-----

*Release date: 20-May-2011*

* brand new parser/matcher that is much more flexible and powerful
* lots of cleaning and a bunch of unittests


0.1
---

*Release date: 10-May-2011*

* fixed a few minor issues & heuristics


0.1b2
-----

*Release date: 12-Mar-2011*

* Added PyPI trove classifiers
* fixed version number in setup.py


0.1b1
-----

*Release date: 12-Mar-2011*

* first pre-release version; imported from Smewt with a few enhancements already
  in there.

